PALM-meteo: palmmeteo.library Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Functions
palmmeteo.library Namespace Reference

## Classes
class | AssimCycle
class | HorizonSelection
class | InputGatherer
class | InputUnitsInfo
class | LatLonRegularGrid
class | LoadedQuantity
class | NCDates
class | PalmPhysics
class | QuantityCalculator
class | TriRegridder
class | UnitConverter

## Functions
| barycentric (tri, pt, isimp)
| verify_palm_hinterp (regridder, lats, lons)
| parse_linspace (space, name, maxerr)

## Detailed Description

    Library functions for plugins

## Function Documentation

## ◆ barycentric()

palmmeteo.library.barycentric | ( |  | tri,
|  |  | pt,
|  |  | isimp
| ) |  |

    Calculate barycentric coordinates of a multi-dimensional point set
    within a triangulation.

    :param pt:      selection of points (multi-dimensional)
    :param isimp:   selection of simplices (same dims as pt)

## ◆ parse_linspace()

palmmeteo.library.parse_linspace | ( |  | space,
|  |  | name,
|  |  | maxerr
| ) |  |

    Verifies that a vector is evenly-spaced and returns the parameters
    of such spacing.

## ◆ verify_palm_hinterp()

palmmeteo.library.verify_palm_hinterp | ( |  | regridder,
|  |  | lats,
|  |  | lons
| ) |  |

    Regrids source lat+lon coordinates to PALM coordinates using the regridder and verifies the result.